#![deny(clippy::all, clippy::pedantic, clippy::restriction)]
#![allow(
  clippy::blanket_clippy_restriction_lints,
  clippy::create_dir,
  clippy::else_if_without_else,
  clippy::enum_glob_use,
  clippy::float_arithmetic,
  clippy::float_cmp,
  clippy::implicit_return,
  clippy::indexing_slicing,
  clippy::integer_arithmetic,
  clippy::integer_division,
  clippy::large_enum_variant,
  clippy::map_unwrap_or,
  clippy::missing_docs_in_private_items,
  clippy::missing_inline_in_public_items,
  clippy::module_name_repetitions,
  clippy::needless_lifetimes,
  clippy::needless_pass_by_value,
  clippy::non_ascii_literal,
  clippy::pattern_type_mismatch,
  clippy::shadow_reuse,
  clippy::struct_excessive_bools,
  clippy::too_many_lines,
  clippy::unseparated_literal_suffix,
  clippy::wildcard_enum_match_arm,
  clippy::wildcard_imports
)]
#![cfg_attr(
  any(test),
  allow(
    clippy::blacklisted_name,
    clippy::expect_fun_call,
    clippy::expect_used,
    clippy::panic,
    clippy::panic_in_result_fn,
    clippy::unwrap_in_result,
    clippy::unwrap_used
  )
)]

#[cfg(test)]
#[macro_use]
pub mod assert_matches;

#[macro_use]
pub mod errln;

#[macro_use]
pub mod err;

#[macro_use]
pub mod out;

#[macro_use]
pub mod outln;

#[cfg(test)]
#[macro_use]
pub mod test_env;

#[cfg(test)]
pub mod test_env_builder;

#[cfg(test)]
pub mod capture;

pub mod arguments;
pub mod bytes;
pub mod common;
pub mod consts;
pub mod env;
pub mod error;
pub mod file_error;
pub mod file_info;
pub mod file_path;
pub mod file_status;
pub mod files;
pub mod hasher;
pub mod host_port;
pub mod host_port_parse_error;
pub mod info;
pub mod infohash;
pub mod input;
pub mod input_stream;
pub mod input_target;
pub mod into_u64;
pub mod into_usize;
pub mod invariant;
pub mod lint;
pub mod linter;
pub mod magnet_link;
pub mod magnet_link_parse_error;
pub mod md5_digest;
pub mod metainfo;
pub mod metainfo_error;
pub mod mode;
pub mod options;
pub mod output_stream;
pub mod output_target;
pub mod piece_length_picker;
pub mod piece_list;
pub mod platform;
pub mod platform_interface;
pub mod print;
pub mod reckoner;
pub mod run;
pub mod sha1_digest;
pub mod shell;
pub mod sort_key;
pub mod sort_order;
pub mod sort_spec;
pub mod status;
pub mod step;
pub mod style;
pub mod subcommand;
pub mod table;
pub mod torrent_summary;
pub mod use_color;
pub mod verifier;
pub mod walker;
pub mod xor_args;

#[cfg(feature = "bench")]
pub mod bench;

pub use run::run;
